//
// Library: Net Responsibility
// Package: Core
// Module:  Options
//
// This file is part of Net Responsibility.
//
// Net Responsibility is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 2 of the License, or
// (at your option) any later version.
//
// Net Responsibility is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Net Responsibility.  If not, see <http://www.gnu.org/licenses/>.
//
// <Options> stores the configurations and other useful variables



#ifndef OPTIONS_H
#define OPTIONS_H

#include <iostream>
#include <stdio.h>
#include <vector>
#include <map>

#include "MyXml.h"
#include "Request.h"

#include "Poco/Exception.h"
#include "Poco/Environment.h"
#include "Poco/Util/Application.h"
#include "Poco/Logger.h"

#if HAVE_CONFIG_H
#include "config.h"
#endif

#define STRINGIFY(path, file) #path #file
#define CONCAT(x, y) STRINGIFY(x, y)

#ifndef DATABASEDIR
#define DATABASEDIR /var/log
#endif

#ifndef PIDDIR
#define PIDDIR /var/run
#endif

#define DATABASEFILE CONCAT(DATABASEDIR, /net-responsibility.db)
#define PIDFILE CONCAT(PIDDIR, /net-responsibility.pid)
#define CONFIGFILE CONCAT(PKGDATADIR, /config.xml)
#define BLACKLISTFILE CONCAT(PKGDATADIR, /blacklist.xml)
#define TXTFILE CONCAT(PKGDATADIR, /txt.xml)
#define REPORT_DIR CONCAT(PKGDATADIR, /reports/)
#define REPORT_MODULE CONCAT(PKGLIBDIR, /report.so)	//Make cross-platform
#define SERVER "www.netresponsibility.com"

#ifndef VERSION
#define VERSION "0"
#endif //VERSION

using Poco::Logger;
using Poco::Util::Application;
using namespace std;

class MainApplication;
class Bypasses;

class Options
{
	public:
		Options();
		Options(int argc, char* argv[]);
		virtual ~Options();

		bool doSaveHistory() const;
		bool doSendImprovementData() const;
		bool doCompressAttachedReport() const;
		bool isReportPart(string) const;
		bool isAttachedReportPart(string) const;
		string getName() const;
		string getUsername() const;
		string getEmailFrom() const;
		string getConfigfile() const;
		string getServer() const;
		string getMacAddress() const;
		string getVersion() const;
		string getDatabasefile() const;
		string getPidfile() const;
		string getBlacklistFile() const;
		string getTxt(string) const;
		string getReportModule() const;
		vector<string> getEmailTo() const;
		vector<string> getReportParts() const;
		vector<string> getAttachedReportParts() const;
		int getReportFrequency() const;
		int getReportStrengthThreshold() const;
		Bypasses &getInitBypasses() const;
		void setUsername(string);
		void loadConfigfile();

	private:
		string _databasefile;
		string _pidfile;
		string _configfile;
		string _txtfile;
		string _username;
		string _name;
		string _emailFrom;
		string _blacklistFile;
		string _version;
		string _server;
		string _reportModule;
		bool _saveHistory;
		bool _sendImprovementData;
		bool _compressAttachedReport;
		vector<string> _reportParts;
		vector<string> _attachedReportParts;
		vector<string> _emailTo;
		map<string, string> _txt;
		int _reportFrequency;
		int _reportStrengthThreshold;
		Logger *_logger;
		Bypasses *_initBypasses;

		void loadDefaultValues();
		void loadTxt();
};

#include "Bypasses.h"
#endif // OPTIONS_H
