//
// Library: Net Responsibility
// Package: Core
// Module:  ReportBase
//
// This file is part of Net Responsibility.
//
// Net Responsibility is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 2 of the License, or
// (at your option) any later version.
//
// Net Responsibility is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Net Responsibility.  If not, see <http://www.gnu.org/licenses/>.
//
// <ReportBase> sets up basic functionality for making/sending reports. Must be
// inherited by <Report>



#ifndef REPORTBASE_H
#define REPORTBASE_H

#include "Options.h"
#include "Database.h"
#include "Bypasses.h"
#include "History.h"
#include "Warnings.h"
#include "Request.h"

#include <sstream>
#include <iostream>
#include <vector>

#include "Poco/Timestamp.h"
#include "Poco/DateTimeFormatter.h"
#include "Poco/Net/MailMessage.h"
#include "Poco/Net/MailRecipient.h"
#include "Poco/Net/SMTPClientSession.h"
#include "Poco/Net/StringPartSource.h"
#include "Poco/Net/FilePartSource.h"
#include "Poco/Net/NetException.h"
#include "Poco/Util/Application.h"
#include "Poco/Exception.h"
#include "Poco/Logger.h"
#include "Poco/URI.h"
#include "Poco/Path.h"


using Poco::Timestamp;
using Poco::DateTimeFormatter;
using Poco::Net::MailMessage;
using Poco::Net::MailRecipient;
using Poco::Net::SMTPClientSession;
using Poco::Net::StringPartSource;
using Poco::Net::FilePartSource;
using Poco::Net::NoAddressFoundException;
using Poco::Util::Application;
using Poco::Exception;
using Poco::Logger;
using Poco::Path;

class MainApplication;

class ReportBase
{
	public:
		ReportBase();
		ReportBase(const ReportBase&);
		virtual ~ReportBase();
		string getBody() const;
		string getSubject() const;
		string getContentType() const;
		void logFinish();
		void sendImprovementData();
		void install();
		void uninstall();
		virtual int send(bool = false);
		virtual void sendCout();
		virtual void sendToFile(char*);
		virtual void test();
		virtual void generate() = 0;
		virtual string name() const = 0;

	protected:
		Options *_options;
		Database *_db;
		Logger *_logger;
		stringstream _body;
		vector<Path> _attachments;
		string _contentType;
		string _subject;
		int _reportId;

		void replaceVar(string&, string, string);
};

#include "MainApplication.h"
#endif // REPORTBASE_H
